namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Container::content_part_name_get( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   const char * __return_value =  ::efl_content_part_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Container::content_get() const
{
    ::Efl_Gfx* __return_value =  ::efl_content_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Container::content_set( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   Eina_Bool __return_value =  ::efl_content_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Container::content_unset() const
{
    ::Efl_Gfx* __return_value =  ::efl_content_unset(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Container::content_remove( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   Eina_Bool __return_value =  ::efl_content_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Container::content_iterate() const
{
   Eina_Iterator * __return_value =  ::efl_content_iterate(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Container::content_count() const
{
   int __return_value =  ::efl_content_count(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
} 
namespace eo_cxx {
namespace efl { 
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type Container::content_part_name_get( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   const char * __return_value =  ::efl_content_part_name_get(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Container::content_get() const
{
    ::Efl_Gfx* __return_value =  ::efl_content_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Container::content_set( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   Eina_Bool __return_value =  ::efl_content_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::Gfx>::type Container::content_unset() const
{
    ::Efl_Gfx* __return_value =  ::efl_content_unset(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::Gfx>::type>(__return_value);
}
inline ::efl::eolian::return_traits<bool>::type Container::content_remove( ::efl::eolian::in_traits< ::efl::Gfx>::type content) const
{
   Eina_Bool __return_value =  ::efl_content_remove(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Gfx*,  ::efl::eolian::in_traits< ::efl::Gfx>::type>(content));
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<bool>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type Container::content_iterate() const
{
   Eina_Iterator * __return_value =  ::efl_content_iterate(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::iterator< ::efl::Gfx>>::type>(__return_value);
}
inline ::efl::eolian::return_traits<int>::type Container::content_count() const
{
   int __return_value =  ::efl_content_count(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline efl::Container::operator ::efl::Container() const { return *static_cast< ::efl::Container const*>(static_cast<void const*>(this)); }
inline efl::Container::operator ::efl::Container&() { return *static_cast< ::efl::Container*>(static_cast<void*>(this)); }
inline efl::Container::operator ::efl::Container const&() const { return *static_cast< ::efl::Container const*>(static_cast<void const*>(this)); }
} }

